==> javie-0.3.13-src.tar.gz: javie-0.3.13-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/services/Font.java <==
/*
 * Copyright (c) 2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.services;

import java.io.File;

public class Font {

	public final String psName;

	public final String fullName;

	public final File fontFile;

	public final int faceIndex;


	public Font(String psName, String fullName, File fontFile, int faceIndex) {
		this.psName = psName;
		this.fullName = fullName;
		this.fontFile = fontFile;
		this.faceIndex = faceIndex;
	}

}

==> javie-0.5.10-src.tar.gz: javie-0.5.10-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/services/Font.java <==
/*
 * Copyright (c) 2010,2011 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.services;

import java.io.File;

public class Font {

	public final String psName;

	public final String fullName;

	public final String familyName;

	public final String subfamilyName;

	public final int weight;

	public final int width;

	public final int fsSelection;

	public final int macStyle;

	public final File fontFile;

	public final int faceIndex;


	public Font(String psName, String fullName,
			String familyName, String subfamilyName,
			int weight, int width, int fsSelection, int macStyle,
			File fontFile, int faceIndex) {

		this.psName = psName;
		this.fullName = fullName;
		this.familyName = familyName;
		this.subfamilyName = subfamilyName;
		this.weight = weight;
		this.width = width;
		this.fsSelection = fsSelection;
		this.macStyle = macStyle;
		this.fontFile = fontFile;
		this.faceIndex = faceIndex;
	}

	public boolean isRegular() {
		if (subfamilyName.equalsIgnoreCase("regular")) {
			return true;
		}
		if (fsSelection != -1 && (fsSelection & (1<<6)) != 0 /*&& width == 5*/) {
			return true;
		}
		if (macStyle != -1 && macStyle == 0) {
			return true;
		}
		return false;
	}

}
